TolyTreeItemDetails<T> class final

完整节点行构建时可使用的状态和标准操作。

Constructors

TolyTreeItemDetails({required TreeNode<T> node, required int depth, required bool isExpanded, required bool isSelected, required bool isFocused, required bool isHovered, required bool isDropTarget, required TolyTreeDropPosition? dropPosition, required VoidCallback onTap, required VoidCallback onToggleExpansion, required VoidCallback onToggleSelection})
const

Properties

depth int
当前节点所在层级。
final
dropPosition TolyTreeDropPosition?
当前拖拽指针对应的放置位置。
final
hashCode int
The hash code for this object.
no setterinherited
isDropTarget bool
当前行是否为有效拖拽目标。
final
isExpanded bool
当前节点是否展开。
final
isFocused bool
当前节点是否为键盘焦点项。
final
isHovered bool
指针是否悬停在当前节点上。
final
isSelected bool
当前节点是否选中。
final
node TreeNode<T>
当前业务节点。
final
onTap VoidCallback
执行当前节点的标准点击行为。
final
onToggleExpansion VoidCallback
切换当前节点展开状态。
final
onToggleSelection VoidCallback
切换当前节点选择状态。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited